@@ -17,11 +17,11 @@ from django.utils.translation import ugettext_lazy as _
 
 from tastypie import fields, bundle, http
 from tastypie.authentication import Authentication,ApiKeyAuthentication
-from tastypie.authorization import Authorization
+from tastypie.authorization import Authorization, ReadOnlyAuthorization
 from tastypie.exceptions import NotFound, BadRequest, InvalidFilterError 
 from tastypie.exceptions import Unauthorized, HydrationError, InvalidSortError, ImmediateHttpResponse
 from tastypie.models import ApiKey
-from tastypie.resources import ModelResource, convert_post_to_patch, dict_strip_unicode_keys
+from tastypie.resources import ModelResource, Resource, convert_post_to_patch, dict_strip_unicode_keys
 from tastypie.utils import trailing_slash
 from tastypie.validation import Validation
 
@@ -32,8 +32,6 @@ from oppia.models import Points, Award, Badge
 from oppia.profile.forms import RegisterForm
 from oppia.signals import course_downloaded
 
-
-
 class UserResource(ModelResource):
     ''' 
     For user login
@@ -218,9 +216,14 @@ class TrackerResource(ModelResource):
             
         # find out the course & activity type from the digest
         try:
-            activity = Activity.objects.get(digest=bundle.data['digest'])
-            bundle.obj.course = activity.section.course
-            bundle.obj.type = activity.type
+            if 'course' in bundle.data:
+                activities = Activity.objects.filter(digest=bundle.data['digest'],section__course__shortname=bundle.data['course'])[:1]
+            else:
+                activities = Activity.objects.filter(digest=bundle.data['digest'])[:1]
+            if activities.count() > 0:
+                activity = activities[0]
+                bundle.obj.course = activity.section.course
+                bundle.obj.type = activity.type
         except Activity.DoesNotExist:
             pass
         
@@ -264,7 +267,7 @@ class TrackerResource(ModelResource):
     
     def patch_list(self,request,**kwargs):
         request = convert_post_to_patch(request)
-        deserialized = self.deserialize(request, request.raw_post_data, format=request.META.get('CONTENT_TYPE', 'application/json'))
+        deserialized = self.deserialize(request, request.body, format=request.META.get('CONTENT_TYPE', 'application/json'))
         for data in deserialized["objects"]:
             data = self.alter_deserialized_detail_data(request, data)
             bundle = self.build_bundle(data=dict_strip_unicode_keys(data))
@@ -287,16 +290,16 @@ class CourseResource(ModelResource):
         allowed_methods = ['get']
         fields = ['id', 'title', 'version', 'shortname']
         authentication = ApiKeyAuthentication()
-        authorization = Authorization() 
+        authorization = ReadOnlyAuthorization() 
         serializer = CourseJSONSerializer()
         always_return_data = True
         include_resource_uri = True
-        
+   
     def prepend_urls(self):
         return [
             url(r"^(?P<resource_name>%s)/(?P<pk>\w[\w/-]*)/download%s$" % (self._meta.resource_name, trailing_slash()), self.wrap_view('download_detail'), name="api_download_detail"),
             ]
-    
+
     def download_detail(self, request, **kwargs):
         self.is_authenticated(request)
         self.throttle_check(request)
@@ -365,33 +368,18 @@ class CourseResource(ModelResource):
             bundle.data['schedule_uri'] = sr.get_resource_uri(schedule)
         
         return bundle
-
-''' This is a temporary fix for any old urls being used 
-TODO: remove this after everyone has moved to new mobile app '''
-class ModuleResource(CourseResource): 
-     class Meta:
-        queryset = Course.objects.all()
-        resource_name = 'module'
-        allowed_methods = ['get']
-        fields = ['id', 'title', 'version', 'shortname']
-        authentication = ApiKeyAuthentication()
-        authorization = Authorization() 
-        serializer = ModuleJSONSerializer()
-        always_return_data = True
-        include_resource_uri = True
     
 class CourseTagResource(ModelResource):
     course = fields.ToOneField('oppia.api.resources.CourseResource', 'course', full=True)
     class Meta:
         queryset = CourseTag.objects.all()
-        allowed_methods = ['get','post']
+        allowed_methods = ['get']
         fields = ['id','course','tag']
         include_resource_uri = False
         authentication = ApiKeyAuthentication()
-        authorization = Authorization()
-        always_return_data = True
-      
-      
+        authorization = ReadOnlyAuthorization()
+        always_return_data = True  
+         
 class ScheduleResource(ModelResource):
     activityschedule = fields.ToManyField('oppia.api.resources.ActivityScheduleResource', 'activityschedule_set', related_name='schedule', full=True, null=True)
     class Meta:
@@ -411,37 +399,25 @@ class ScheduleResource(ModelResource):
 class TagResource(ModelResource):
     count = fields.IntegerField(readonly=True)
     courses = fields.ToManyField('oppia.api.resources.CourseTagResource', 'coursetag_set', related_name='tag', full=True)
-
+  
     class Meta:
         queryset = Tag.objects.filter(courses__isnull=False).distinct().order_by("name")
         resource_name = 'tag'
         allowed_methods = ['get']
         fields = ['id','name']
         authentication = ApiKeyAuthentication()
-        authorization = Authorization() 
+        authorization = ReadOnlyAuthorization() 
         always_return_data = True
         include_resource_uri = False
         serializer = TagJSONSerializer()
     
-    def dehydrate(self,bundle):
-        return bundle
-    
     def dehydrate_count(self,bundle):
+        #if bundle.request.user.is_staff:
         count = Course.objects.filter(tag__id=bundle.obj.id).count()
+        #else:
+        #    count = Course.objects.filter(tag__id=bundle.obj.id, staff_only=False).count()
         return count
     
-    def tag_detail(self, request, **kwargs):
-        self.is_authenticated(request)
-        self.throttle_check(request)
-        
-        name = kwargs.pop('name', None)
-        courses = Course.objects.filter(tag__name=name)
-        
-        for c in courses:
-            obj = CourseResource().build_bundle(obj=c, request=request)
-            
-        response = HttpResponse(name+str(courses), content_type='')
-        return response
              
 class ActivityScheduleResource(ModelResource):
     schedule = fields.ToOneField('oppia.api.resources.ScheduleResource', 'schedule', related_name='activityschedule')
@@ -583,4 +559,8 @@ class ScorecardResource(ModelResource):
     def dehydrate_quiz_secs(self,bundle):
         start_date = datetime.datetime.now() - datetime.timedelta(days=14)
         end_date = datetime.datetime.now()
-        return Tracker.activity_secs(user=bundle.obj,type='quiz',start_date=start_date,end_date=end_date)
\ No newline at end of file
+        return Tracker.activity_secs(user=bundle.obj,type='quiz',start_date=start_date,end_date=end_date)
+    
+
+    
+    
\ No newline at end of file
